cd "/Users/HoZhang"
log using "Author_Response_Log", replace
/* 
The code generates the "Replication Study (Second Wave)" panel of the table 
on page 5 of "Author Response to Replication of Ho and Zhang (2008)"

Content of the code file:
(A) Data Description
(B) Data Preparation
(C) Data Analysis
*/

**************************
** (A) Data Description **
**************************
/*
The replication team collected data in two waves:
the first wave was collected prior to the original submission 
of the replication-summary paper to Management Science;
the second wave was collected thereafter.

The table on page 2 of the author response compares data from
the original study with data from the first wave of replication
shared by the replication team upon collection.

The table on page 5 of the author response compares data from
the original study with data from the second wave of replication
subsequently shared by the replication team upon collection. 
*/

**************************
** (B) Data Preparation **
**************************

** Import second-wave data from UTD
import delimited dataAll_UTD_update_Fall2022.csv, clear 

* Select second-wave observations, those with "Fall" in the date variable
keep if strpos(date, "Fall") > 0 

* Save second-wave data from UTD
save UTD.dta, replace

** Import second-wave data from UM
import delimited dataAll_UM.csv, clear 

* All UM data were collected in the second wave, hence no need for selection

* Change variable p to string type to be consistent with the UTD data
tostring p, replace

* Save second-wave data from UM
save UM.dta, replace

** Concatenate second-wave data from UTD and second-wave data from UM
use UTD.dta, clear 
append using UM.dta

** Generate variables, use percentage format for acceptance and efficiency
gen AcceptCode = (accept=="Accept")*100
gen TotalProfit = rprofit+sprofit
gen Efficiency = TotalProfit/16*100
gen RetailPrice = 10-q

** Label the TPT (two-part tariff) indicator
label define tpt_label 0 "QD" 1 "TPT"
label values tpt tpt_label

** Save second-wave data
save data_second_wave.dta, replace


***********************
** (C) Data Analysis **
***********************
/* 
Variable definition:
w: Wholesale price
f: Fixed fee
RetailPrice: Retail price
AcceptCode: Acceptance (%)
Efficiency: Efficiency (%)

Note: 
Subjects play in pairs, as Player A (manufacturer) or Player B (retailer). 
Using the observations for Player A (or Player B) alone suffices to 
capture observations of players in both roles in the following analysis.
*/

** Compare variable means between the TPT and QD conditions
use data_second_wave.dta, clear

* Wholesale price
ttest w if myname == "Player A", by(tpt)

* Fixed fee
ttest f if myname == "Player A", by(tpt)

* Retail price (if accept)
ttest RetailPrice if myname == "Player A" & AcceptCode == 100, by(tpt)

* Acceptance (%)
ttest AcceptCode if myname == "Player A", by(tpt)

* Efficiency (%)
ttest Efficiency if myname == "Player A", by(tpt)

log close
translate Author_Response_Log.smcl Author_Response_Log.pdf, replace
